@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -19,7 +19,6 @@
 
 from __future__ import division, print_function, absolute_import
 
-import os
 import re
 import sys
 import math
@@ -28,8 +27,6 @@ import codecs
 import platform
 import importlib
 from base64 import b64encode
-from decimal import Context, Decimal, Inexact
-from hashlib import sha1
 from collections import namedtuple
 
 try:
@@ -56,10 +53,6 @@ def bit_length(n):
     return n.bit_length()
 
 
-def float_to_decimal(f):
-    return Decimal(f)
-
-
 if PY3:
     def str_to_bytes(s):
         return s.encode(a_good_encoding())
@@ -73,7 +66,6 @@ if PY3:
     ARG_NAME_ATTRIBUTE = 'arg'
     integer_types = (int,)
     hunichr = chr
-    from functools import reduce
 
     def unicode_safe_repr(x):
         return repr(x)
@@ -98,15 +90,9 @@ def quiet_raise(exc):
     def int_to_bytes(i, size):
         return i.to_bytes(size, 'big')
 
-    def bytes_from_list(ls):
-        return bytes(ls)
-
     def to_bytes_sequence(ls):
         return bytes(ls)
 
-    def zero_byte_sequence(n):
-        return bytes(n)
-
     def int_to_byte(i):
         return bytes([i])
 
@@ -130,9 +116,6 @@ else:
         def struct_unpack(fmt, string):
             return struct.unpack(fmt, str(string))
 
-    def zero_byte_sequence(n):
-        return hbytes(b'\0' * n)
-
     def int_from_bytes(data):
         assert isinstance(data, bytearray)
         if CAN_UNPACK_BYTE_ARRAY:
@@ -165,9 +148,6 @@ else:
 
     int_to_byte = chr
 
-    def bytes_from_list(ls):
-        return hbytes(bytearray(ls))
-
     def to_bytes_sequence(ls):
         return bytearray(ls)
 
@@ -229,7 +209,6 @@ else:
     ARG_NAME_ATTRIBUTE = 'id'
     integer_types = (int, long)
     hunichr = unichr
-    reduce = reduce
 
     def escape_unicode_characters(s):
         return codecs.encode(s, 'string_escape')
